==> zio-aws-waf_2.13-5.17.104.1-sources.jar: zio/aws/waf/model/ListLoggingConfigurationsResponse.scala <==
package zio.aws.waf.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.waf.model.primitives.NextMarker
import scala.jdk.CollectionConverters._
final case class ListLoggingConfigurationsResponse(
    loggingConfigurations: Option[
      Iterable[zio.aws.waf.model.LoggingConfiguration]
    ] = None,
    nextMarker: Option[NextMarker] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.waf.model.ListLoggingConfigurationsResponse = {
    import ListLoggingConfigurationsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.waf.model.ListLoggingConfigurationsResponse
      .builder()
      .optionallyWith(
        loggingConfigurations.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.loggingConfigurations)
      .optionallyWith(
        nextMarker.map(value => NextMarker.unwrap(value): java.lang.String)
      )(_.nextMarker)
      .build()
  }
  def asReadOnly: zio.aws.waf.model.ListLoggingConfigurationsResponse.ReadOnly =
    zio.aws.waf.model.ListLoggingConfigurationsResponse.wrap(buildAwsValue())
}
object ListLoggingConfigurationsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.waf.model.ListLoggingConfigurationsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.waf.model.ListLoggingConfigurationsResponse =
      zio.aws.waf.model.ListLoggingConfigurationsResponse(
        loggingConfigurations.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextMarker.map(value => value)
      )
    def loggingConfigurations
        : Option[List[zio.aws.waf.model.LoggingConfiguration.ReadOnly]]
    def nextMarker: Option[NextMarker]
    def getLoggingConfigurations: ZIO[Any, AwsError, List[
      zio.aws.waf.model.LoggingConfiguration.ReadOnly
    ]] =
      AwsError.unwrapOptionField("loggingConfigurations", loggingConfigurations)
    def getNextMarker: ZIO[Any, AwsError, NextMarker] =
      AwsError.unwrapOptionField("nextMarker", nextMarker)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.waf.model.ListLoggingConfigurationsResponse
  ) extends zio.aws.waf.model.ListLoggingConfigurationsResponse.ReadOnly {
    override val loggingConfigurations
        : Option[List[zio.aws.waf.model.LoggingConfiguration.ReadOnly]] = scala
      .Option(impl.loggingConfigurations())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.waf.model.LoggingConfiguration.wrap(item)
        }.toList
      )
    override val nextMarker: Option[NextMarker] = scala
      .Option(impl.nextMarker())
      .map(value => zio.aws.waf.model.primitives.NextMarker(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.waf.model.ListLoggingConfigurationsResponse
  ): zio.aws.waf.model.ListLoggingConfigurationsResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-waf_2.13-5.19.8.4-sources.jar: zio/aws/waf/model/ListLoggingConfigurationsResponse.scala <==
package zio.aws.waf.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.waf.model.primitives.NextMarker
import scala.jdk.CollectionConverters._
final case class ListLoggingConfigurationsResponse(
    loggingConfigurations: Optional[
      Iterable[zio.aws.waf.model.LoggingConfiguration]
    ] = Optional.Absent,
    nextMarker: Optional[NextMarker] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.waf.model.ListLoggingConfigurationsResponse = {
    import ListLoggingConfigurationsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.waf.model.ListLoggingConfigurationsResponse
      .builder()
      .optionallyWith(
        loggingConfigurations.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.loggingConfigurations)
      .optionallyWith(
        nextMarker.map(value => NextMarker.unwrap(value): java.lang.String)
      )(_.nextMarker)
      .build()
  }
  def asReadOnly: zio.aws.waf.model.ListLoggingConfigurationsResponse.ReadOnly =
    zio.aws.waf.model.ListLoggingConfigurationsResponse.wrap(buildAwsValue())
}
object ListLoggingConfigurationsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.waf.model.ListLoggingConfigurationsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.waf.model.ListLoggingConfigurationsResponse =
      zio.aws.waf.model.ListLoggingConfigurationsResponse(
        loggingConfigurations.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextMarker.map(value => value)
      )
    def loggingConfigurations
        : Optional[List[zio.aws.waf.model.LoggingConfiguration.ReadOnly]]
    def nextMarker: Optional[NextMarker]
    def getLoggingConfigurations: ZIO[Any, AwsError, List[
      zio.aws.waf.model.LoggingConfiguration.ReadOnly
    ]] =
      AwsError.unwrapOptionField("loggingConfigurations", loggingConfigurations)
    def getNextMarker: ZIO[Any, AwsError, NextMarker] =
      AwsError.unwrapOptionField("nextMarker", nextMarker)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.waf.model.ListLoggingConfigurationsResponse
  ) extends zio.aws.waf.model.ListLoggingConfigurationsResponse.ReadOnly {
    override val loggingConfigurations
        : Optional[List[zio.aws.waf.model.LoggingConfiguration.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.loggingConfigurations())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.waf.model.LoggingConfiguration.wrap(item)
          }.toList
        )
    override val nextMarker: Optional[NextMarker] = zio.aws.core.internal
      .optionalFromNullable(impl.nextMarker())
      .map(value => zio.aws.waf.model.primitives.NextMarker(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.waf.model.ListLoggingConfigurationsResponse
  ): zio.aws.waf.model.ListLoggingConfigurationsResponse.ReadOnly = new Wrapper(
    impl
  )
}
